Session class

Constructors

Session(IBaseSession _baseSession)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String procedure, {List? args, Map<String, dynamic>? kwargs, Map<String, dynamic>? options}) Future<Result>
close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(String topic, {List? args, Map<String, dynamic>? kwargs, Map<String, dynamic>? options}) Future<void>?
register(String procedure, Result endpoint(Invocation invocation)) Future<Registration>
subscribe(String topic, void endpoint(Event event)) Future<Subscription>
toString() String
A string representation of this object.
inherited
unregister(Registration reg) Future<void>
unsubscribe(Subscription sub) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited